==> scilab_5.1.1.orig.tar.gz: scilab-5.1.1/modules/graphics/src/c/getHandleProperty/get_callback_type_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_callback_type_property.c                                     */
/* desc : function to retrieve in Scilab the callback_type field of       */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"

/*------------------------------------------------------------------------*/
int get_callback_type_property( sciPointObj * pobj )
{
	int type = 0;

	if(sciGetEntityType (pobj) == SCI_UIMENU)
	{
		type = pUIMENU_FEATURE(pobj)->callbackType;
	}
	else if (sciGetEntityType (pobj) == SCI_UICONTROL)
	{
		type = pUICONTROL_FEATURE(pobj)->callbackType;
	}
	else
	{
		Scierror(999, _("%s property does not exist for this handle.\n"),"callback_type");
		return -1;
		}

		return sciReturnDouble(type);
  
}
/*------------------------------------------------------------------------*/

==> scilab_5.3.1.orig.tar.gz: scilab-5.3.1/modules/graphics/src/c/getHandleProperty/get_callback_type_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_callback_type_property.c                                     */
/* desc : function to retrieve in Scilab the callback_type field of       */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"

/*------------------------------------------------------------------------*/
int get_callback_type_property( sciPointObj * pobj )
{
	int type = 0;

	if(sciGetEntityType (pobj) == SCI_UIMENU)
	{
		type = pUIMENU_FEATURE(pobj)->callbackType;
	}
	else if (sciGetEntityType (pobj) == SCI_UICONTROL)
	{
		type = pUICONTROL_FEATURE(pobj)->callbackType;
	}
	else
	{
		Scierror(999, _("'%s' property does not exist for this handle.\n"),"callback_type");
		return -1;
		}

		return sciReturnDouble(type);
  
}
/*------------------------------------------------------------------------*/
